%	load_TS.m		MATLAB function
%	
%	head_TS retrieves header information from TS data. In case
%	of BEAR data this is done by reading the .head files with
%	function head_BEAR.
%	head_TS is mainly a function which decides which data type
%	to process and calls the respective routines.
%	Those return the header information in structure head.
%       After that, calling of find_skip returns a vector skip 
%       - the number of seconds(! not samples) to skip in the resp. 
%       data files.
%	head_TS in turn passes these values on and initializes the 
%	component/channel toggles.
%
%	USAGE: function [head,skip] = head_TS(cfile)
%
function [head,skip] = head_ts(cfile)

global format nstat ext l3ns l4ns hsmp sc_factor

nstat = size(char(cfile),1);
data = [];
nchan = [];

for k = 1:nstat
   if (format(k) == 1)
      % ASCII data not supported @ moment!!!
      set(findobj('Tag','Messages'),'String','Calling head_asc');
      [head(k)] = head_asc(cfile,k);
   elseif(format(k) == 2)
      set(findobj('Tag','Messages'),'String','Calling head_bear')
      [head(k)] = head_bear(cfile,k);
   elseif(format(k) == 3)
      set(findobj('Tag','Messages'),'String','Calling head_egb')
      [head(k)] = head_egb(cfile,k);  
   elseif(format(k) == 4)
      set(findobj('Tag','Messages'),'String','Calling head_tsh/tsl')
      [head(k)] = head_mtu(cfile,k);  
   elseif(format(k) == 5)
      set(findobj('Tag','Messages'),'String','Calling head_lims')
      [head(k)] = head_lims(cfile,k);
   elseif(format(k) == 6)
      set(findobj('Tag','Messages'),'String','Calling head_nims')
      [head(k)] = head_nims(cfile,k);  
   end
   for l = 1:5
      c_temp = ['UseDat(',num2str(k),',',num2str(l),')'];
      if l<=size(sc_factor,2)
        if (sc_factor(k,l) ~= 0) set(findobj('Tag',c_temp),'Value',1); end;
      end
   end 
end

% get the number of samples to skip in each file to align data at
% latest start time 
[skip,max_skip,i_tmax,i_tmin] = find_skip(head);

return
  
