%	read_BEAR   MATLAB function 
% 	
%	reads data from a BEAR TS file. Input is file name. Returns array data 
%	of nchan x npoints, and start time structure
%
%	USAGE: [data,start] = read_BEAR(cfile)
%

function [data,start] = load_BEAR(cfile)
  % get the number of stations involved
  nstat = size(cfile,1);
  % now loop through the header files and extract the start time and
  % sampling interval
  for k = 1:nstat
    ll = length(cfile(k,:) - 4;
    cfile_head = [cfile(k,1:ll),'head'];
    fid = fopen(cfile_head,'r');
    ctemp = fgets(fid);
    % 	find the start time of the data
    while (isempty(findstr(ctemp,'>START_TIME')))
      ctemp = fgets(fid);
    end
    n = findstr(ctemp,':');	% eliminate everything before :
    b=str2num(ctemp(n+1:length(ctemp-1)));  % crack the string
    start(k) = struct('year',b(1),'mon',b(2),'day',b(3),'hr', ...
        b(4),'min',b(5),'sec',b(6));  %  put into structure
    %
    %		find DELTA_T (sampling rate in s)
    while (isempty(findstr((ctemp),'>DELTA_T')))
      ctemp = fgets(fid);
    end
    n = findstr(ctemp,':');	% elimante everything before :
    start.dt = str2num(ctemp(n+1:length(ctemp-1)));  % add to structure
    
    %		find NCHAN
    while (isempty(findstr((ctemp),'>NCHAN')))
      ctemp = fgets(fid);
    end
    n = findstr(ctemp,':');	% eliminate everything before :
    nch = str2num(ctemp(n+1))
    fclose(fid);
  end
  % get the number of samples to skip in each file to align data at
  % latest start time 
  [skip] = find_skip(start);
  
  cfile_bin = [cfile(1:ll),'bin'];

  fid = fopen(cfile_bin);
  [data] = fread(fid,[5,inf],'float32');
  data = data';

  
  return
  