%	plot_TS.m		MATLAB script 
%
%	plots time series of magnetic field data
%   

function [naxes] = plot_TS(cfile,skip,head,naxes)
  global fid_bin sc_factor format ext
  
  nstat = size(char(cfile),1);
  nsec = str2num(get(findobj('Tag','NSeconds'),'String'));
  form = get(findobj('Tag','PopupFormat'),'Value');
  
  [comps,naxes] = get_comps(naxes);
  
  symcol = ['b';'r';'g'];
  % if (form == 5) 
  %  Y_labs = ['E_x [mV/km]';'E_y [mV/km]';'  H_x [nT] ';'  H_y [nT] ';'  H_z [nT] '];
  %else
    Y_labs = ['  H_x [nT] ';'  H_y [nT] ';'  H_z [nT] ';'E_x [mV/km]';'E_y [mV/km]'];
  %end
  
  min_dt = min([head.dt]);
  max_dt = max([head.dt]);
  for k=1:nstat
      if ((char(ext(k,1:3)) == 'tsl' | char(ext(k,1:3)) == 'ts4') & nsec/min_dt > 5000)
        min_dt = 1
     end
  end       
  
  % decimate data in case
  for k = 1:nstat
    decimation(k) = 1;
    if (~(char(ext(k,1:3)) == 'tsl' | char(ext(k,1:3)) == 'ts4'))
        while(nsec/(decimation(k)*head(k).dt) > 50000) decimation(k) = decimation(k)*10; end 
    end
  end
  comps_idx = find(sum(comps));
  % stat_idx not used.
  stat_idx  = find(sum(comps'));

  iax = 0;
  for ic = comps_idx
      
     iax = iax + 1;
     c_temp = ['Ax(',num2str(iax),')'];
     axes(findobj('Tag',c_temp));
     
     for k = 1:nstat
        if (comps(k,ic) == 1)
            if (format(k) == 2)
                [data] = bin_bear(head,skip,nsec,k);
            elseif (format(k) == 3)
                [data] = bin_egb(head,skip,nsec,k);
            elseif (format(k) == 4)
                [data] = bin_mtu(head,skip,nsec,k);
            elseif (format(k) == 5)
                [data] = bin_lims(head,skip,nsec,k);
            elseif (format(k) == 6)
                [data] = bin_nims(head,skip,nsec,k);
            end
            if (~(char(ext(k,1:3)) == 'tsl' | char(ext(k,1:3)) == 'ts4') | nsec/head(k).dt <= 5000)
                scale = sc_factor(k,:)'*ones(1,round(nsec/head(k).dt));
                data = data.*scale;
                ndata = round(nsec/head(k).dt);
                samp_nums = [1:decimation(k):ndata] * (head(k).dt/min_dt) - (head(k).dt/min_dt-1);
            elseif ((char(ext(k,1:3)) == 'tsl' | char(ext(k,1:3)) == 'ts4') & nsec/head(k).dt > 5000)
                scale = sc_factor(k,:)'*ones(1,nsec);
                data = data.*scale;
                ndata = nsec;
                samp_nums = [1:ndata];
            end
            plot(samp_nums,data(ic,1:decimation(k):ndata)-data(ic,1),symcol(k,:));
            hold on;
       end
     end
  
     ylabel(Y_labs(ic,:));
     hold off;
     
     ntics = 5;
     delta = round(nsec/ntics);
     if (delta == 0) delta = 1; end;
     ntics = floor(nsec/delta);
     for i = 1:ntics
        xtick(i) = (i-1)*delta/min_dt + 1;
        xlabel(i,:) = find_time_string(head,skip,(i-1)*delta);
     end
     xtick(ntics+1) = nsec/min_dt;
     xlabel(ntics+1,:) = find_time_string(head,skip,nsec);
     set(gca,'Tag',c_temp,'Xgrid','on','Ygrid','on',...
             'XLim',[1,nsec/min_dt],...
             'XTickLabelMode','manual','XTickLabel',xlabel,...
        	   	'XTickMode','manual','XTick',xtick);
     if( iax ~= naxes)
       set(gca,'Xticklabel',[]);
     end
  end

return